@@ -129,6 +129,16 @@ class SteamApp(object):
         """
         return not self.is_proton and self.prefix_path_exists and self.appid
 
+    @property
+    def is_proton_ready(self):
+        """
+        Return True if the Proton installation is ready for use.
+
+        Proton installation might be incomplete if it hasn't been launched
+        yet, in which case the Proton binaries don't exist yet.
+        """
+        return bool(self.proton_dist_path)
+
     @property
     def proton_dist_path(self):
         """
@@ -302,15 +312,22 @@ def find_steam_path():
 
         return None, None
 
-    # If we're inside a Flatpak sandbox,
-    # prioritize Flatpak installation of Steam
-    steam_dirs_to_search = (
-        [".var/app/com.valvesoftware.Steam/data/Steam"] + COMMON_STEAM_DIRS
-        if is_flatpak_sandbox()
-        else COMMON_STEAM_DIRS
-    )
+    if is_flatpak_sandbox():
+        # If we're inside a Flatpak sandbox,
+        # prioritize Flatpak installation of Steam.
+        # In this case, ensure we don't mix steam_root and steam_path
+        # from Flatpak and non-Flatpak installations of Steam.
+        steam_path = \
+            Path.home() / ".var/app/com.valvesoftware.Steam/data/Steam"
+        if has_steamapps_dir(steam_path):
+            logger.info(
+                "Found Steam directory at %s. You can also define Steam "
+                "directory manually using $STEAM_DIR",
+                steam_path
+            )
+            return steam_path, steam_path
 
-    for steam_path in steam_dirs_to_search:
+    for steam_path in COMMON_STEAM_DIRS:
         # The common Steam directories are found inside the home directory
         steam_path = Path.home() / steam_path
         if has_steamapps_dir(steam_path):
@@ -664,11 +681,29 @@ def get_steam_lib_paths(steam_path):
         for value in library_entries:
             if isinstance(value, dict):
                 # Library data is stored in a dict in newer Steam releases
-                library_folders.append(Path(value["path"]))
+                path = Path(value["path"])
             else:
                 # Older releases just store the library path as a string
                 # and nothing else
-                library_folders.append(Path(value))
+                path = Path(value)
+
+            xdg_steam_path = Path.home() / ".local/share/Steam"
+            flatpak_steam_path = \
+                Path.home() / ".var/app/com.valvesoftware.Steam/data/Steam"
+
+            is_library_folder_xdg_steam = str(path) == str(xdg_steam_path)
+            is_flatpak_steam = str(steam_path) == str(flatpak_steam_path)
+
+            # Adjust the path if the library folder is "~/.local/share/Steam"
+            # and we're looking for library folders in
+            # "~/.var/app/com.valvesoftware.Steam"
+            # This is because ~/.local/share/Steam inside a Steam Flatpak
+            # sandbox corresponds to a different location, and we need to
+            # adjust for that.
+            if is_library_folder_xdg_steam and is_flatpak_steam:
+                path = flatpak_steam_path
+
+            library_folders.append(path)
 
         logger.info(
             "Found %d Steam library folders", len(library_folders)
