@@ -15,7 +15,7 @@ def home_cwd(home_dir, monkeypatch):
 class TestCLIRun:
     def test_run_executable(
             self, steam_app_factory, default_proton,
-            command, gui_provider, launch_cli):
+            commands, gui_provider, launch_cli):
         """
         Run an EXE file by selecting using the GUI
         """
@@ -27,13 +27,14 @@ class TestCLIRun:
         launch_cli(["test.exe"])
 
         # 'test.exe' was executed
+        command = commands[-1]
         assert command.args.startswith("wine ")
         assert command.args.endswith("/test.exe'")
 
         assert command.env["WINEPREFIX"] == str(steam_app.prefix_path)
 
     def test_run_executable_appid(
-            self, default_proton, steam_app_factory, command, launch_cli):
+            self, default_proton, steam_app_factory, commands, launch_cli):
         """
         Run an EXE file directly for a chosen game
         """
@@ -42,6 +43,7 @@ class TestCLIRun:
         launch_cli(["--appid", "10", "test.exe"])
 
         # 'test.exe' was executed
+        command = commands[-1]
         assert command.args.startswith("wine ")
         assert command.args.endswith("/test.exe'")
 
@@ -106,17 +108,50 @@ class TestCLIRun:
         steam_app_factory(name="Fake game", appid=10)
 
         launch_cli([
-            "--verbose", "--no-bwrap", "--no-runtime", "--appid", "10",
-            "test.exe"
+            "--verbose", "--no-bwrap", "--no-runtime", "--no-term", "--appid",
+            "10", "test.exe"
         ])
 
         # CLI flags are passed through to the main CLI entrypoint
-        assert cli_args[0:4] == [
-            "--verbose", "--no-runtime", "--no-bwrap", "-c"
+        assert cli_args[0:5] == [
+            "--verbose", "--no-runtime", "--no-bwrap", "--no-term", "-c"
         ]
-        assert cli_args[4].startswith("wine ")
-        assert cli_args[4].endswith("test.exe'")
-        assert cli_args[5] == "10"
+        assert cli_args[5].startswith("wine ")
+        assert cli_args[5].endswith("test.exe'")
+        assert cli_args[6] == "10"
+
+    @pytest.mark.parametrize("argument", [
+        None,
+        "--background-wineserver",
+        "--no-background-wineserver"
+    ])
+    def test_run_executable_passthrough_background_wineserver(
+            self, launch_cli, monkeypatch, steam_app_factory,
+            argument):
+        """
+        Try running an EXE file and apply given wineserver argument.
+        If the argument is set, it should also be passed to the main
+        entrypoint.
+        """
+        cli_args = []
+
+        monkeypatch.setattr(
+            "protontricks.cli.launch.cli_main",
+            cli_args.extend
+        )
+
+        steam_app_factory(name="Fake game", appid=10)
+
+        extra_args = [argument] if argument else []
+        launch_cli(extra_args + ["--appid", "10", "test.exe"])
+
+        if argument:
+            # Ensure the corresponding argument was passd to the main CLI
+            # entrypoint
+            assert argument in cli_args
+        else:
+            assert "--background-wineserver" not in cli_args
+            assert "--no-background-wineserver" not in cli_args
 
     def test_cli_error_handler_uncaught_exception(
             self, launch_cli, default_proton, steam_app_factory, monkeypatch,
