@@ -7,7 +7,7 @@ import pytest
 
 class TestCLIRun:
     def test_run_winetricks(
-            self, cli, steam_app_factory, default_proton, command,
+            self, cli, steam_app_factory, default_proton, commands,
             home_dir):
         """
         Perform a Protontricks command directly for a certain game
@@ -19,6 +19,7 @@ class TestCLIRun:
         cli(["10", "winecfg"], env={"STEAM_RUNTIME": "0"})
 
         # winecfg was actually run
+        command = commands[-1]
         assert str(command.args[0]).endswith(".local/bin/winetricks")
         assert command.args[1] == "winecfg"
 
@@ -37,7 +38,7 @@ class TestCLIRun:
         )
 
     def test_run_winetricks_shortcut(
-            self, cli, shortcut_factory, default_proton, command,
+            self, cli, shortcut_factory, default_proton, commands,
             steam_dir):
         """
         Perform a Protontricks command for a non-Steam shortcut
@@ -48,13 +49,14 @@ class TestCLIRun:
         cli(["4149337689", "winecfg"])
 
         # Default Proton is used
+        command = commands[-1]
         assert command.env["PROTON_PATH"] == str(proton_install_path)
         assert command.env["WINEPREFIX"] == str(
             steam_dir / "steamapps" / "compatdata" / "4149337689" / "pfx")
 
     def test_run_winetricks_select_proton(
             self, cli, steam_app_factory, default_proton,
-            custom_proton_factory, command, home_dir):
+            custom_proton_factory, commands, home_dir):
         """
         Perform a Protontricks command while selecting a specific
         Proton version using PROTON_VERSION env var
@@ -63,10 +65,11 @@ class TestCLIRun:
         custom_proton = custom_proton_factory(name="Custom Proton")
         cli(["10", "winecfg"], env={"PROTON_VERSION": "Custom Proton"})
 
-        assert command.env["PROTON_PATH"] == str(custom_proton.install_path)
+        assert commands[-1].env["PROTON_PATH"] \
+            == str(custom_proton.install_path)
 
     def test_run_winetricks_select_steam(
-            self, cli, steam_app_factory, default_proton, command,
+            self, cli, steam_app_factory, default_proton, commands,
             home_dir):
         """
         Perform a Protontricks command while selecting a specific
@@ -87,6 +90,7 @@ class TestCLIRun:
             env={"STEAM_DIR": str(home_dir / ".steam_new")}
         )
 
+        command = commands[-1]
         assert command.env["WINE"] == str(
             home_dir / ".cache" / "protontricks" / "proton"
             / "Proton 4.20" / "bin" / "wine"
@@ -98,7 +102,7 @@ class TestCLIRun:
 
     def test_run_winetricks_steam_runtime_v1(
             self, cli, steam_app_factory, steam_runtime_dir, default_proton,
-            command, home_dir):
+            commands, home_dir):
         """
         Perform a Protontricks command using the older Steam Runtime
         bundled with Steam
@@ -113,6 +117,7 @@ class TestCLIRun:
         )
 
         # winecfg was actually run
+        command = commands[-1]
         assert str(command.args[0]).endswith(".local/bin/winetricks")
         assert command.args[1] == "winecfg"
         assert command.env["PATH"].startswith(str(wine_bin_dir))
@@ -125,6 +130,7 @@ class TestCLIRun:
 
         assert command.env["LEGACY_STEAM_RUNTIME_PATH"] == \
             str(steam_runtime_dir / "steam-runtime")
+        assert command.env["PROTONTRICKS_STEAM_RUNTIME"] == "legacy"
         assert "STEAM_RUNTIME_PATH" not in command.env
 
         for name in ("wine", "wineserver"):
@@ -135,13 +141,12 @@ class TestCLIRun:
 
             content = path.read_text()
 
-            # The script template for legacy Steam Runtime is used
+            # Correct binary names used in the scripts
             assert "\"$PROTON_DIST_PATH\"/bin/{}".format(name) in content
-            assert "PROTONTRICKS_INSIDE_STEAM_RUNTIME" not in content
 
     def test_run_winetricks_steam_runtime_v2(
             self, cli, home_dir, steam_app_factory, steam_runtime_dir,
-            steam_runtime_soldier, command, proton_factory, caplog):
+            steam_runtime_soldier, commands, proton_factory, caplog):
         """
         Perform a Protontricks command using a newer Steam Runtime that is
         installed as its own application
@@ -159,7 +164,17 @@ class TestCLIRun:
             / "bin"
         )
 
+        # Launcher process was launched to handle launching processes
+        # inside the sandbox
+        assert commands[0].args == str(wine_bin_dir / "bwrap-launcher")
+
+        # keepalive wineserver process launched in background to improve
+        # Wine command launch time
+        assert commands[1].args == str(wine_bin_dir / "wineserver-keepalive")
+
         # winecfg was run
+        command = commands[-1]
+
         assert str(command.args[0]).endswith(".local/bin/winetricks")
         assert command.args[1] == "winecfg"
         assert command.env["PATH"].startswith(str(wine_bin_dir))
@@ -177,6 +192,7 @@ class TestCLIRun:
             str(steam_runtime_dir / "steam-runtime")
         assert command.env["STEAM_RUNTIME_PATH"] == \
             str(steam_runtime_soldier.install_path)
+        assert command.env["PROTONTRICKS_STEAM_RUNTIME"] == "bwrap"
 
         # No warning will be created since Steam Runtime Soldier is recognized
         # by Protontricks
@@ -194,13 +210,12 @@ class TestCLIRun:
 
             content = path.read_text()
 
-            # The script template for bwrap-based Steam Runtime is used
+            # Correct binary names used in the scripts
             assert "\"$PROTON_DIST_PATH\"/bin/{}".format(name) in content
-            assert "PROTONTRICKS_INSIDE_STEAM_RUNTIME" in content
 
     def test_run_winetricks_steam_runtime_v2_no_bwrap(
             self, cli, home_dir, steam_app_factory, steam_runtime_dir,
-            steam_runtime_soldier, command, proton_factory, caplog):
+            steam_runtime_soldier, commands, proton_factory, caplog):
         """
         Perform a Protontricks command using a newer Steam Runtime
         *without* bwrap that is installed as its own application
@@ -218,6 +233,7 @@ class TestCLIRun:
             / "bin"
         )
 
+        command = commands[-1]
         # winecfg was run
         assert str(command.args[0]).endswith(".local/bin/winetricks")
         assert command.args[1] == "winecfg"
@@ -243,6 +259,7 @@ class TestCLIRun:
             str(steam_runtime_dir / "steam-runtime")
         assert command.env["STEAM_RUNTIME_PATH"] == \
             str(steam_runtime_soldier.install_path)
+        assert command.env["PROTONTRICKS_STEAM_RUNTIME"] == "legacy"
 
         # No warning will be created since Steam Runtime Soldier is recognized
         # by Protontricks
@@ -260,12 +277,58 @@ class TestCLIRun:
 
             content = path.read_text()
 
-            # The script template for normal Steam Runtime is used
             assert "\"$PROTON_DIST_PATH\"/bin/{}".format(name) in content
-            assert "PROTONTRICKS_INSIDE_STEAM_RUNTIME" not in content
+
+    @pytest.mark.parametrize(
+        "args,wineserver_launched",
+        [
+            # background wineserver enabled for bwrap by default
+            (["-c", "'echo nothing'", "20"], True),
+
+            # background wineserver disabled by default for everything else
+            (["--no-bwrap", "-c", "'echo nothing'", "20"], False),
+
+            # Manually disable background wineserver
+            (
+                ["--no-background-wineserver", "-c", "'echo nothing'", "20"],
+                False
+            ),
+
+            # Manually enable background wineserver
+            (
+                [
+                    "--background-wineserver", "--no-bwrap",
+                    "-c", "'echo nothing'", "20"
+                ],
+                True
+            )
+        ]
+    )
+    def test_run_background_wineserver_toggle(
+            self, cli, steam_app_factory, default_new_proton, commands,
+            args, wineserver_launched, home_dir):
+        """
+        Try running a Protontricks command with different arguments
+        and ensure background wineserver is (not) launched
+        depending on the scenario
+        """
+        steam_app_factory(name="Fake game 1", appid=20)
+
+        cli(args)
+
+        wineserver_found = any(
+            True for command in commands
+            if isinstance(command.args, str)
+            and command.args == str(
+                home_dir / ".cache/protontricks/proton/Proton 7.0/bin"
+                / "wineserver-keepalive"
+            )
+        )
+
+        assert wineserver_found == wineserver_launched
 
     def test_run_winetricks_game_not_found(
-            self, cli, steam_app_factory, default_proton, command):
+            self, cli, steam_app_factory, default_proton):
         """
         Try running a Protontricks command for a non-existing app
         """
@@ -405,9 +468,28 @@ class TestCLIRun:
             record.getMessage()
         )
 
+    def test_run_command_proton_incomplete(
+            self, cli, steam_app_factory, default_proton):
+        """
+        Try performing a Protontricks command using a Proton installation that
+        is incomplete because it hasn't been launched yet.
+
+        Regression test for
+        https://github.com/flathub/com.github.Matoking.protontricks/issues/10
+        """
+        # Remove the 'dist' directory to make the Proton installation
+        # incomplete
+        shutil.rmtree(str(default_proton.install_path / "dist"))
+
+        steam_app_factory(name="Fake game", appid=10)
+
+        result = cli(["10", "winecfg"], expect_returncode=1)
+
+        assert "Proton installation is incomplete" in result
+
     def test_run_command_runtime_incomplete(
             self, cli, steam_app_factory, steam_runtime_soldier,
-            command, proton_factory, steam_dir):
+            proton_factory, steam_dir):
         """
         Try performing a Protontricks command using a Proton installation that
         is still missing a Steam Runtime installation.
@@ -521,8 +603,8 @@ class TestCLIRun:
 
 class TestCLIGUI:
     def test_run_gui(
-            self, cli, default_proton, steam_app_factory, gui_provider, command,
-            home_dir):
+            self, cli, default_proton, steam_app_factory, gui_provider,
+            commands, home_dir):
         """
         Start the GUI and fake selecting a game
         """
@@ -534,6 +616,7 @@ class TestCLIGUI:
 
         cli(["--gui"])
 
+        command = commands[-1]
         # 'winetricks --gui' was run for the game selected by user
         assert str(command.args[0]) == \
             str(home_dir / ".local" / "bin" / "winetricks")
@@ -566,8 +649,8 @@ class TestCLIGUI:
 
 class TestCLICommand:
     def test_run_command(
-            self, cli, default_proton, steam_app_factory, gui_provider, command,
-            home_dir):
+            self, cli, default_proton, steam_app_factory, gui_provider,
+            commands, home_dir):
         """
         Run a shell command for a given game
         """
@@ -576,11 +659,13 @@ class TestCLICommand:
 
         cli(["-c", "bash", "10"])
 
+        command = commands[-1]
+
         # The command is just 'bash'
         assert command.args == "bash"
 
-        assert command.kwargs["cwd"] == str(steam_app.install_path)
-        assert command.kwargs["shell"] is True
+        assert command.cwd == str(steam_app.install_path)
+        assert command.shell is True
 
         # Correct environment vars were set
         assert command.env["WINE"] == str(
