@@ -1,4 +1,4 @@
-import os
+import logging
 import random
 import shutil
 import struct
@@ -37,6 +37,9 @@ def cleanup():
     # between tests
     get_gui_provider.cache_clear()
 
+    # Clear log handlers
+    logging.getLogger("protontricks").handlers.clear()
+
 
 @pytest.fixture(scope="function", autouse=True)
 def home_dir(monkeypatch, tmp_path):
@@ -94,6 +97,26 @@ def steam_root(steam_dir):
     yield steam_dir.parent / "root"
 
 
+@pytest.fixture(scope="function")
+def flatpak_sandbox(monkeypatch, tmp_path):
+    """
+    Fake Flatpak sandbox running under Flatpak 1.12.1
+    """
+    flatpak_info_path = tmp_path / "flatpak-info"
+
+    flatpak_info_path.write_text(
+        "[Application]\n"
+        "name=fake.flatpak.Protontricks\n"
+        "\n"
+        "[Instance]\n"
+        "flatpak-version=1.12.1"
+    )
+
+    monkeypatch.setattr(
+        "protontricks.util.FLATPAK_INFO_PATH", str(flatpak_info_path)
+    )
+
+
 @pytest.fixture(scope="function", autouse=True)
 def steam_runtime_dir(steam_dir):
     """
@@ -549,6 +572,17 @@ def default_proton(proton_factory):
     )
 
 
+@pytest.fixture(scope="function")
+def default_new_proton(proton_factory, steam_runtime_soldier):
+    """
+    Mocked newer default Proton installation that uses separate Steam Runtime
+    """
+    return proton_factory(
+        name="Proton 7.0", appid=543210, compat_tool_name="proton_70",
+        is_default_proton=True, required_tool_app=steam_runtime_soldier
+    )
+
+
 @pytest.fixture(scope="function")
 def steam_library_factory(steam_dir, steam_libraryfolders_path, tmp_path):
     """
@@ -588,9 +622,15 @@ def steam_library_factory(steam_dir, steam_libraryfolders_path, tmp_path):
 
 class MockSubprocess:
     def __init__(
-            self, args=None, kwargs=None, mock_stdout=None, env=None):
+            self, args=None, kwargs=None, mock_stdout=None, check=False,
+            cwd=None, shell=False, env=None, **_):
         self.args = args
         self.kwargs = kwargs
+        self.check = check
+        self.shell = shell
+        self.cwd = cwd
+        self.pid = 5
+        self.returncode = 0
 
         if not mock_stdout:
             self.mock_stdout = ""
@@ -599,6 +639,12 @@ class MockSubprocess:
 
         self.env = env
 
+    def wait(self):
+        pass
+
+    def terminate(self):
+        pass
+
 
 class MockResult:
     def __init__(self, stdout, returncode=0):
@@ -633,34 +679,48 @@ def gui_provider(monkeypatch):
 
 
 @pytest.fixture(scope="function")
-def command(monkeypatch):
+def commands(monkeypatch):
     """
-    Monkeypatch the subprocess.run to store the args and environment
-    variables passed to the last executed command
+    Fixture containing all the commands called using subprocess during
+    the test run
     """
-    mock_command = MockSubprocess()
+    commands_ = []
 
-    def mock_subprocess_run(args, **kwargs):
+    def mock_subprocess_run(*args, **kwargs):
         # Don't mock "/sbin/ldconfig"
         if args[0] == "/sbin/ldconfig":
             return run(args, **kwargs)
 
-        mock_command.args = args
-        mock_command.kwargs = kwargs
-        mock_command.env = os.environ.copy()
+        mock_command = MockSubprocess(
+            *args,
+            **kwargs
+        )
+
+        commands_.append(mock_command)
 
         return MockResult(stdout=b"")
 
+    def mock_Popen(*args, **kwargs):
+        mock_command = MockSubprocess(*args, **kwargs)
+
+        commands_.append(mock_command)
+
+        return mock_command
+
     monkeypatch.setattr(
         "protontricks.util.run",
         mock_subprocess_run
     )
+    monkeypatch.setattr(
+        "protontricks.util.Popen",
+        mock_Popen
+    )
     monkeypatch.setattr(
         "protontricks.cli.desktop_install.run",
         mock_subprocess_run
     )
 
-    yield mock_command
+    return commands_
 
 
 def _run_cli(monkeypatch, capsys, cli_func):
