@@ -289,6 +289,42 @@ class TestFindLibraryPaths:
         assert steam_dir in library_paths
         assert library_dir in library_paths
 
+    def test_get_steam_lib_paths_adjust_flatpak_steam_path(
+            self, steam_dir, steam_library_factory, home_dir):
+        """
+        Retrieve Steam library folders and ensure that the
+        "~/.local/share/Steam" path is adjusted in the library folder
+        configuration file if Steam is installed using Flatpak.
+
+        Regression test for flathub/com.github.Matoking.protontricks#10
+        """
+        flatpak_steam_dir = \
+            home_dir / ".var/app/com.valvesoftware.Steam/data/Steam"
+        flatpak_steam_dir.mkdir(parents=True)
+        steam_dir.rename(str(flatpak_steam_dir))
+        shutil.rmtree(str(home_dir / ".local"))
+
+        libraryfolders_data = {
+            "libraryfolders": {
+                "0": {
+                    "path": str(home_dir / ".local/share/Steam")
+                }
+            }
+        }
+        (flatpak_steam_dir / "steamapps/libraryfolders.vdf").write_text(
+            vdf.dumps(libraryfolders_data), "utf-8"
+        )
+
+        library_paths = get_steam_lib_paths(
+            home_dir / ".var/app/com.valvesoftware.Steam/data/Steam"
+        )
+        # The only library folder should point under "~/.var/app", even if the
+        # path in the configuration file is "~/.local/share/Steam".
+        # This needs to be done to adjust for the different path in the
+        # Steam Flatpak sandbox.
+        assert len(library_paths) == 1
+        assert str(library_paths[0]) == str(flatpak_steam_dir)
+
 
 class TestFindAppidProtonPrefix:
     def test_find_appid_proton_prefix_steamapps_case(
@@ -388,6 +424,30 @@ class TestFindSteamPath:
         assert str(steam_paths[0]) == str(custom_path)
         assert str(steam_paths[1]) == str(custom_path)
 
+    def test_find_steam_path_flatpak(
+            self, steam_dir, steam_root, tmp_path, home_dir, flatpak_sandbox,
+            monkeypatch):
+        """
+        Ensure that `steam_path` and `steam_root` both point to the Flatpak
+        installation of Steam if Flatpak installation is found.
+
+        Regression test for flathub/com.github.Matoking.protontricks#10
+        """
+        # Create a symlink to act as the Flatpak installation to keep the test
+        # simple.
+        steam_flatpak_dir = (
+            home_dir / ".var" / "app" / "com.valvesoftware.Steam" / "data"
+            / "Steam"
+        )
+        steam_flatpak_dir.parent.mkdir(parents=True)
+        steam_flatpak_dir.symlink_to(steam_dir)
+
+        # Since Flatpak is enabled, both paths should point to Flatpak
+        steam_path, steam_root = find_steam_path()
+
+        assert str(steam_path) == str(steam_flatpak_dir)
+        assert str(steam_root) == str(steam_flatpak_dir)
+
 
 class TestGetSteamApps:
     def test_get_steam_apps_custom_proton(
